@@ -10,7 +10,20 @@ from typing import Annotated, TypeAlias
 from annotated_types import MinLen
 from pydantic import BaseModel, Field
 from pydantic_ai import Agent, ModelRetry, RunContext, format_as_xml
-from pixie import pixie_app
+import pixie.sdk as pixie
+
+
+class SqlGenVariables(pixie.Variables):
+    db_schema: str
+    today_date: str
+    sql_examples: str
+
+
+sql_gen_agent_prompt = pixie.create_prompt(
+    "sql_gen_agent",
+    SqlGenVariables,
+    description="Generates SQL queries from natural language for PostgreSQL databases",
+)
 
 
 # Simulated database schema
@@ -88,18 +101,13 @@ agent = Agent[Deps, Response](
 
 @agent.system_prompt
 async def system_prompt() -> str:
-    return f"""\
-Given the following PostgreSQL table of records, your job is to
-write a SQL query that suits the user's request.
-
-Database schema:
-
-{DB_SCHEMA}
-
-today's date = {date.today()}
-
-{format_as_xml(SQL_EXAMPLES)}
-"""
+    return sql_gen_agent_prompt.compile(
+        SqlGenVariables(
+            db_schema=DB_SCHEMA,
+            today_date=str(date.today()),
+            sql_examples=format_as_xml(SQL_EXAMPLES),
+        )
+    )
 
 
 @agent.output_validator
@@ -130,8 +138,8 @@ async def validate_output(ctx: RunContext[Deps], output: Response) -> Response:
     return output
 
 
-@pixie_app
-async def sql_gen(query: str) -> str:
+@pixie.app
+async def pydantic_ai_sql_gen(query: str) -> str:
     """SQL generation agent with multi-step workflow and validation.
 
     This example demonstrates:
@@ -146,7 +154,6 @@ async def sql_gen(query: str) -> str:
     Returns:
         Generated SQL query or error message
     """
-    Agent.instrument_all()
 
     deps = Deps(validate_sql=True)
     result = await agent.run(query, deps=deps)
@@ -173,7 +180,7 @@ async def test():
         print(f"\n{'='*60}")
         print(f"Query: {query}")
         print("=" * 60)
-        result = await sql_gen(query)
+        result = await pydantic_ai_sql_gen(query)
         print(result)
 
 
